# If you use Bourne shell derivatives (eg. Bash), source this file to set up
# your environment to use lscsoft software.

# turn on verbose (with -v option) to see what's happening to your system
myverbosity=0

# only print messages when verbose option is on
userenv_report()
{
  if [ $myverbosity -eq 1 ]
  then
    echo $1
  fi

  return 0
}

# check for the verbose option
while getopts "v" Option
do
  case $Option in
    v ) myverbosity=1;;
  esac
done
shift $(($OPTIND - 1))

# If the .nolscsoft or .noall file exists, do not setup anything
if [ -f ${HOME}/.noanything ]; then
    userenv_report "Automatic setup of lscsoft *disabled* by ~/.noanything"
    return 0
fi
# for those whose dialects respect double negatives ;)
if [ -f ${HOME}/.nonothing ]; then
    userenv_report "Automatic setup of lscsoft *disabled* by ~/.nonothing"
    return 0
fi
    
# Turn off lscsoft inparticular
if [ -f ${HOME}/.nolscsoft ]; then
    userenv_report "Automatic setup of lscsoft *disabled* by ~/.nolscsoft"
    return 0
fi


LSCSOFT_PREFIX=/opt/lscsoft
export LSCSOFT_PREFIX

## Now begin filters based on individual packages

PKGLIST_A="libmetaio libframe"

# Handle package list A
for name in $PKGLIST_A ; do
    if [ -f ${HOME}/.nolscsoft-$name ]; then
        NOSETUP_A="$NOSETUP_A $name"
    else
        PKGSETUP_A="$PKGSETUP_A $name"
    fi
done

# Handle LAL package
if [ -f ${HOME}/.nolscsoft-lal ]; then
    NOSETUP_LAL="lal"
fi


### Now actually perform the environment setup.
# print header
userenv_report "+++++++++++++++++++++++ lscsoft environment +++++++++++++++++++++++"
userenv_report "  Package	Vers.	Path"
userenv_report " "

# Package set A setup
for directory in $PKGSETUP_A ; do
	if [ -d "${LSCSOFT_PREFIX}/${directory}" ] ; then
		PATH=${LSCSOFT_PREFIX}/${directory}/bin:${PATH}
		PKG_CONFIG_PATH=${LSCSOFT_PREFIX}/${directory}/lib/pkgconfig:${PKG_CONFIG_PATH}
		LD_LIBRARY_PATH=${LSCSOFT_PREFIX}/${directory}/lib:${LD_LIBRARY_PATH}
		MANPATH=${LSCSOFT_PREFIX}/${directory}/man:${MANPATH}
		export PATH PKG_CONFIG_PATH LD_LIBRARY_PATH MANPATH
        
        ver=" "
        ver=`grep Version ${LSCSOFT_PREFIX}/${directory}/lib/pkgconfig/${directory}.pc| awk '{print $NF}'`
        userenv_report "+ $directory	$ver	${LSCSOFT_PREFIX}/${directory}"
	fi
done

# Package A disability report
for name in $NOSETUP_A ; do
	userenv_report "- $name	*Disabled* by ~/.nolscsoft-$name"
done

# LAL package setup
if [ -z $NOSETUP_LAL ]; then
    if [ -d "${LSCSOFT_PREFIX}/lal" ] ; then 
        LAL_LOCATION=${LSCSOFT_PREFIX}/lal
        export LAL_LOCATION	
        source ${LAL_LOCATION}/etc/lal-user-env.sh
        ver=" "
        ver=`lal-version | grep 'LAL Version:' | awk '{print $NF}'`
        userenv_report "+ lal		$ver	${LSCSOFT_PREFIX}/lal"
    fi
else
	userenv_report "- lal		*Disabled* by ~/.nolscsoft-lal"
fi

# print footer
userenv_report " "
userenv_report "++ Note: some packages might be overridden by your own profile. ++"
### Fin

